==> lazy_widget-1.0.3.tar.gz: lib/src/widget/common_tabbar_widget.dart <==
import 'package:flutter/material.dart';
import 'keep_state_widget.dart';

typedef OnTabSelected<T> = void Function(int index, T value);
typedef TabViewBuilder<T> = Widget Function(int index, T value);

class CommonTabBarWidget<T> extends StatefulWidget {
  final int initialIndex;
  final List<T> tabValues;
  final TabViewBuilder<T> tabBuilder;
  final TabViewBuilder<T> tabViewBuilder;
  final OnTabSelected<T>? onTabSelected;
  final SizedBox? tabTopChild;
  final SizedBox? tabBottomChild;
  final Widget? bottomSheet;

  CommonTabBarWidget(
      {this.initialIndex = 0,
      required this.tabValues,
      required this.tabBuilder,
      required this.tabViewBuilder,
      this.onTabSelected,
      this.tabTopChild,
      this.tabBottomChild,
      this.bottomSheet});

  @override
  _CommonTabBarWidgetState createState() {
    return _CommonTabBarWidgetState();
  }
}

class _CommonTabBarWidgetState extends State<CommonTabBarWidget>
    with SingleTickerProviderStateMixin {
  late TabController tabController;
  late VoidCallback listener;

  @override
  void initState() {
    super.initState();
    tabController = TabController(
        length: widget.tabValues.length,
        vsync: this,
        initialIndex: widget.initialIndex);
    listener = () {
      int index = tabController.index;
      if (widget.onTabSelected != null) {
        widget.onTabSelected!(index, widget.tabValues[index]);
      }
    };
    tabController.addListener(listener);
  }

  @override
  void dispose() {
    tabController.removeListener(listener);
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    var _tabBar = TabBar(
      controller: tabController,
      labelPadding: EdgeInsets.all(0),
      indicatorWeight: 3,
      indicatorSize: TabBarIndicatorSize.label,
      unselectedLabelColor: Color(0xFF71777D),
      tabs: widget.tabValues
          .map((t) => widget.tabBuilder(widget.tabValues.indexOf(t), t))
          .toList(),
    );
    var top = widget.tabTopChild ?? const SizedBox();
    var bottom = widget.tabBottomChild ?? const SizedBox();
    return Scaffold(
        backgroundColor: Colors.transparent,
        appBar: PreferredSize(
            preferredSize: Size.fromHeight(_tabBar.preferredSize.height +
                (top.height ?? 0) +
                (bottom.height ?? 0)),
            child: Column(
              mainAxisAlignment: MainAxisAlignment.center,
              children: <Widget>[top, _tabBar, bottom],
            )),
        bottomSheet: widget.bottomSheet,
        body: TabBarView(
          controller: tabController,
          children: widget.tabValues.map((t) {
            return KeepStateWidget(
              child: widget.tabViewBuilder(widget.tabValues.indexOf(t), t),
            );
          }).toList(),
        ));
  }
}

==> lazy_widget-2.0.0.tar.gz: lib/src/widget/common_tabbar_widget.dart <==
import 'package:flutter/material.dart';
import 'keep_state_widget.dart';

typedef OnTabSelected<T> = void Function(int index, T value);
typedef TabViewBuilder<T> = Widget Function(int index, T value);

// ignore: must_be_immutable
class CommonTabBarWidget<T> extends StatefulWidget {
  final int initialIndex;
  final List<T> tabValues;
  final TabViewBuilder<T> tabBuilder;
  final TabViewBuilder<T> tabViewBuilder;
  final OnTabSelected<T>? onTabSelected;
  final SizedBox? tabTopChild;
  final SizedBox? tabBottomChild;
  final Widget? bottomSheet;

  CommonTabBarWidget(
      {this.initialIndex = 0,
      required this.tabValues,
      required this.tabBuilder,
      required this.tabViewBuilder,
      this.onTabSelected,
      this.tabTopChild,
      this.tabBottomChild,
      this.bottomSheet});

  _CommonTabBarWidgetState? _state;

  @override
  _CommonTabBarWidgetState createState() {
    _state = _CommonTabBarWidgetState();
    return _state!;
  }

  TabController get tabController => _state!.tabController;
}

class _CommonTabBarWidgetState extends State<CommonTabBarWidget>
    with SingleTickerProviderStateMixin {
  late TabController tabController;
  late VoidCallback listener;

  @override
  void initState() {
    super.initState();
    tabController = TabController(
        length: widget.tabValues.length,
        vsync: this,
        initialIndex: widget.initialIndex);
    listener = () {
      int index = tabController.index;
      if (widget.onTabSelected != null) {
        widget.onTabSelected!(index, widget.tabValues[index]);
      }
    };
    tabController.addListener(listener);
  }

  @override
  void dispose() {
    tabController.removeListener(listener);
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    var _tabBar = TabBar(
      controller: tabController,
      labelPadding: EdgeInsets.all(0),
      indicatorWeight: 3,
      indicatorSize: TabBarIndicatorSize.label,
      unselectedLabelColor: Color(0xFF71777D),
      tabs: widget.tabValues
          .map((t) => widget.tabBuilder(widget.tabValues.indexOf(t), t))
          .toList(),
    );
    var top = widget.tabTopChild ?? const SizedBox();
    var bottom = widget.tabBottomChild ?? const SizedBox();
    return Scaffold(
        backgroundColor: Colors.transparent,
        appBar: PreferredSize(
            preferredSize: Size.fromHeight(_tabBar.preferredSize.height +
                (top.height ?? 0) +
                (bottom.height ?? 0)),
            child: Column(
              mainAxisAlignment: MainAxisAlignment.center,
              children: <Widget>[top, _tabBar, bottom],
            )),
        bottomSheet: widget.bottomSheet,
        body: TabBarView(
          controller: tabController,
          children: widget.tabValues.map((t) {
            return KeepStateWidget(
              child: widget.tabViewBuilder(widget.tabValues.indexOf(t), t),
            );
          }).toList(),
        ));
  }
}
